@@ -1,12 +1,12 @@
-from db import db
+from ext import EXT_CONTEXT
 from sqlalchemy import Column, Integer, String
 
-class Role(db.Model):
 
+class Role(EXT_CONTEXT["db"].Model):
     __tablename__ = 'role'
 
     id = Column(Integer, primary_key=True, autoincrement=True)
     name = Column(String(20))
 
     def __init__(self, name):
-        self.name = name
\ No newline at end of file
+        self.name = name
